/*
  StepperL293.h - Stepper Library to use with L293 chip.
  Created by Martin Nawrath and Andreas Muxel, 2008.
  http://interface.khm.de
  Released into the public domain.
*/

#ifndef StepperL293_h
#define StepperL293_h


class StepperL293
{
  public:
	// constructor
    StepperL293();
	// attach
	void attach(int pin1, int pin2, int pin3, int pin4, int numberOfSteps);
	// set mode (default half-step)
	void setMode(int Mode);
	// set power
	void setPower(int power);
	// set speed
	void setSpeed(long speed);
	// set step
	void setStep(int step);
	// get step
	int getStep(void);
	// drive
	void drive();
	// get status step ready
	int stepReady(void);
	// debugger
	int debugger(void);
	
  private:
	// motor pins
	int _motorPin1;
	int _motorPin2;
	int _motorPin3;
	int _motorPin4;
	// number of steps
	int _numberOfSteps;
	// mode
    int _stepperMode;
	// pwm
	unsigned long _pwmValue;
	unsigned long _pwm23Value;
	unsigned long _pwm1A;
	unsigned long _pwm1B;
	// speed
	unsigned long _delaySpeed;
	unsigned long _lastTimeSpeed;
	// drive parameters
	int _directionStepper;
	int _localStep;
	unsigned long _currentStep;
	int _referenceStep;
	int _differenceSteps;
	// step ready status
	int _stepReadyStatus;
};

#endif

